mercurial/debugcommands.py
changeset 49249 db19f6be0442
parent 49248 63fd0282ad40
child 49250 61cf3d39fd9e
--- a/mercurial/debugcommands.py	Mon May 30 16:18:12 2022 +0200
+++ b/mercurial/debugcommands.py	Mon May 30 11:30:48 2022 +0200
@@ -1865,12 +1865,12 @@
 
 
 @command(
-    b'debugindex',
+    b'debug-revlog-index|debugindex',
     cmdutil.debugrevlogopts + cmdutil.formatteropts,
     _(b'-c|-m|FILE'),
 )
 def debugindex(ui, repo, file_=None, **opts):
     """dump index data for a storage primitive"""
     opts = pycompat.byteskwargs(opts)
     store = cmdutil.openstorage(repo, b'debugindex', file_, opts)
@@ -1865,12 +1865,12 @@
 )
 def debugindex(ui, repo, file_=None, **opts):
-    """dump index data for a storage primitive"""
+    """dump index data for a revlog"""
     opts = pycompat.byteskwargs(opts)
     store = cmdutil.openstorage(repo, b'debugindex', file_, opts)